@@ -1,3 +1,17 @@
+# Copyright 2001 by Roger Bivand
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+
+
 read.gal <- function(file, row.names=NULL) 
 {
 	con <- file(file, open="r")
@@ -25,6 +39,7 @@ read.gal <- function(file, row.names=NULL)
     	attr(res, "region.id") <- row.names
 	attr(res, "gal") <- TRUE
 	attr(res, "call") <- TRUE
+	res <- sym.attr.nb(res)
 	invisible(res)
 }
 
