@@ -11,12 +11,13 @@
 #  GNU General Public License for more details.
 #
 
-relativeneigh <- function(x) {
+relativeneigh <- function(coords) {
+    x <- coords
     if (!is.matrix(x)) stop("Data not in matrix form")
     if (any(is.na(x))) stop("Data cannot include NAs")
     np <- nrow(x)
     if(ncol(x)!=2) stop("Only works in 2d")
-    g1<-g2<-rep(0,np*2)
+    g1<-g2<-rep(0,np*3)
     nogab <- 0
     z <- .C("compute_relative", np=as.integer(np), from=as.integer(g1),
              to=as.integer(g2), nedges=as.integer(nogab),
@@ -24,11 +25,11 @@ relativeneigh <- function(x) {
     z$from<-z$from[1:z$nedges]
     z$to<-z$to[1:z$nedges]
     attr(z, "call") <- match.call()
-    class(z)<-"relative"
+    class(z)<-c("Graph","relative")
     invisible(z)
 }
 
-plot.relative<-function(rel, show.points=FALSE, add=FALSE, linecol=par(col),...){
+plot.relative<-function(x, show.points=FALSE, add=FALSE, linecol=par(col),...){
   if(!add) plot(rel$x,rel$y,type='n')
   segments(rel$x[rel$from],rel$y[rel$from],
            rel$x[rel$to],rel$y[rel$to],col=linecol)
